amachine.am_transition API documentation

# amachine.am_transition

View Source

     1from dataclasses import dataclass
     2from fractions import Fraction
     3
     4@dataclass
     5class Transition :
     6	origin_state_idx : int
     7	target_state_idx : int
     8	prob : float
     9	symbol_idx : int
    10	pq : Fraction | None = None

@dataclass
class Transition: View Source

     5@dataclass
     6class Transition :
     7	origin_state_idx : int
     8	target_state_idx : int
     9	prob : float
    10	symbol_idx : int
    11	pq : Fraction | None = None

Transition( origin_state_idx: int, target_state_idx: int, prob: float, symbol_idx: int, pq: fractions.Fraction | None = None)
origin_state_idx: int
target_state_idx: int
prob: float
symbol_idx: int
pq: fractions.Fraction | None = None